@@ -178,7 +178,7 @@ def test_scaled_font_get_scale_matrix(scaled_font):
     assert isinstance(scaled_font.get_scale_matrix(), cairo.Matrix)
 
 
-# https://bitbucket.org/pypy/pypy/issues/2741
+# https://foss.heptapod.net/pypy/pypy/-/issues/2741
 @pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_scaled_font_text_extents(scaled_font):
     with pytest.raises(TypeError):
@@ -194,7 +194,7 @@ def test_scaled_font_glyph_extents(scaled_font):
         scaled_font.glyph_extents()
 
 
-# https://bitbucket.org/pypy/pypy/issues/2741
+# https://foss.heptapod.net/pypy/pypy/-/issues/2741
 @pytest.mark.skipif(platform.python_implementation() == "PyPy", reason="PyPy")
 def test_toy_font_face():
     with pytest.raises(TypeError):
@@ -204,6 +204,10 @@ def test_toy_font_face():
 def test_toy_font_get_family():
     font_face = cairo.ToyFontFace("")
     assert isinstance(font_face.get_family(), str)
+    font_face = cairo.ToyFontFace("serif")
+    assert isinstance(font_face.get_family(), str)
+    font_face = cairo.ToyFontFace("sans-serif")
+    assert isinstance(font_face.get_family(), str)
 
 
 def test_toy_font_get_slant():
