@@ -211,6 +211,16 @@ def test_pdf_set_metadata():
         surface.set_metadata(cairo.PDFMetadata.AUTHOR, "author")
 
 
+@pytest.mark.skipif(not hasattr(cairo.PDFSurface, "set_custom_metadata"),
+                    reason="too old cairo")
+def test_pdf_set_custom_metadata():
+    fileobj = io.BytesIO()
+    with cairo.PDFSurface(fileobj, 128, 128) as surface:
+        surface.set_custom_metadata("ISBN", "978-0123456789")
+        with pytest.raises(cairo.Error):
+            surface.set_custom_metadata("Author", "Author isn't allowed")
+
+
 @pytest.mark.skipif(not hasattr(cairo.PDFSurface, "add_outline"),
                     reason="too old cairo")
 def test_pdf_add_outline():
@@ -739,3 +749,11 @@ def test_recording_surface():
 
     surface = cairo.RecordingSurface(cairo.CONTENT_COLOR, None)
     assert surface.ink_extents() == (0.0, 0.0, 0.0, 0.0)
+
+
+@pytest.mark.skipif(not hasattr(cairo.Format, "RGB96F"), reason="too old cairo")
+def test_format_rgbf():
+    surface = cairo.ImageSurface(cairo.Format.RGB96F, 3, 3)
+    assert surface.get_format() == cairo.Format.RGB96F
+    surface = cairo.ImageSurface(cairo.Format.RGBA128F, 3, 3)
+    assert surface.get_format() == cairo.Format.RGBA128F
